## {{page-title}}

This page gives guidance on the representation of constructs like:

- Representing structured addresses using <code>Address</code>.
- Representing structured names using <code>HumanName</code>
- Representing contact methods such as telephones using <code>ContactPoint</code>.

### Address

A physical address(es) for the organization, location and patient.

{{render:http://hl7.org/fhir/StructureDefinition/Address}}

in addition to base [Address](https://www.hl7.org/fhir/datatypes.html#Address), Estonian _address_ includes an [EHAK](https://simplifier.net/ee-base/extension-eebase-ehak) and [ADS](https://simplifier.net/ee-base/extension-eebase-ads) extensions. 

<br/><code>use</code><br/>
Values from [AddressUse](https://www.hl7.org/fhir/valueset-address-use.html) CodeSystem.
- work - allowed in case of Organization and Location
- home - allowed in Patient resources
- temp - as place of unknown patient finding

<br/><code>type</code><br/>
Don't have business meaning.

<br/><code>text</code><br/>
Textual presentation of address, shown in the lists

<br/><code>line</code><br/>
Text with the street, house and appartment number. Only informative. Don't have business meaning.

<br/><code>city</code><br/>
Textual presentation of administrative unit name. Suitable for any unit type: city, borough, village. . Only informative. Don't have business meaning.

<br/><code>district</code><br/>
Textual presentation of parish. Only informative. Don't have business meaning.

<br/><code>state</code><br/>
Textual presentation of county. Shiuld be used according with EHAK classifier, for example "Harju maakond" instead of "Harjumaa".

<br/><code>country</code><br/>
[ISO 3166](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-3) 3 letter code.

<br/><code>period</code><br/>
Period of address usage

<br/><code>EHAK</code><br/>
Code from EHAK classifier. Specified code will be validated against the latest version of EHAK classifier. In case of exact version of EHAK the _Coding.version_ attribute should be specified.

<textarea rows="8" cols="80" style="border:none;"> 
  <extension url="https://hl7.ee/fhir/StructureDefinition/Extension-EEBase-EHAK">
    <valueCoding>
      <system value="http://fhir.hl7.ee/id/ehak-number"/>
      <version value="2021v3"/>
      <code value="2928"/>
      <display value="Kehra linn"/>
    </valueCoding>
  </extension>
</textarea>  

<br/><code>ADS</code><br/>
Address ID from Estonian address register.

---
