## {{page-title}}

<div class="alert alert-warning">

**Work in progress.**\
This section of the Implementation Guide is subject to change.

</div>

In order to promote consistency and make it easier for implementers to locate suitable profiles, extensions, value sets, etc, for their projects, a naming strategy will be adopted for EE Base defined FHIR assets or FHIR assets derived from the EE Base. All EE Base derived implementation guides and FHIR assets MUST follow these rules to claim conformace with the EE Base.

For detailed definitions of concepts discussed within this guidance document, refer to the appropriate published version of the [FHIR standard](https://www.hl7.org/fhir/).

<br/>

<div class="card border-success mb-3" id="fhir-name-01">
  <div class="card-header bg-warning">
   <strong class="card-title"><i class="bi bi-check-circle-fill"></i> FHIR-NAME-01 Convention for Profile definition</strong>
   <a href="#fhir-name-01"><i class="bi bi-link-45deg"></i></a>
  </div>
  <div class="card-body">
    <ul>
      <li>FHIR Profile name MUST follow an agreed format.</li>
      <li>The url of a profile consists of a number of name segments, and will be in the form: <br/>https://[<b>base url</b>]/fhir/StructureDefinition/[<b>Base</b>]-[<b>FHIRAssetName</b>]-[<b>BusinessName1</b>]-[<b>BusinessName2</b>]
        <ul>
          <li><b>Base url:</b> The <b>url</b> used for standard publishing. For example: <a href="#">hl7.org</a> for HL7 International and <a href="#">hl7.ee</a> for HL7 Estonia. Check full <a href="/guide/ee-fhir-base/Home/Policy/Health-Services.guide.md?version=current">list</a> for details.</li>
          <li><b>Base:</b> The provider name. <b>EEBase</b> for Estonian Base. <b>Mandatory</b></li>
          <li><b>FHIRAssetName:</b> The name of the base FHIR Resource. <b>Mandatory</b></li>            
          <li><b>BusinessNames:</b> Business names used only where there are mutiple profiles for a given base resource type. <b>Optional</b></li>
          <li>No business version information is allowed in the  resource url</li>
          <li>Segment names in FHIR Profile name MUST follow an Pascal case convention except brand names.</li> 
        </ul>  
<div class="callout callout-success">
    <strong>Examples</strong>
    <br/>
    EEBase-Patient
    <br/>
    EEBase-Patient-Unknown
    <br/>
    EEBase-Observation-EducationLevel
    <br/>
    RETS-MedicationRequest
    <br/>
    EEHIF-MedicationRequest-Inpatient
</div>         
      </li>     
      <li><b>Resource name:</b> The [<b>Base</b>], [<b>FHIRAssetName</b>] and [<b>BusinessNames</b>] without hyphen (-)  SHOULD be used as resource name.</li>            
      <li><b>Resource id:</b> The specification does not specify the form of resource id. [<b>Base</b>]-[<b>FHIRAssetName</b>]-[<b>BusinessNames</b>] with hyphen (-) RECOMMENDED for this purpose.</li>  
      <li><b>Title:</b> The title of the resource MUST be the [<b>Base</b>], [<b>FHIRAssetName</b>] and [<b>BusinessNames</b>] with added spaces to make it human readable and understandable.</li>             
    </ul>

<div class="callout callout-success">
<strong>Example of Estonian base Organization definition</strong><br/> 
<textarea rows="7" cols="80" style="border:none;"> 
<StructureDefinition xmlns="http://hl7.org/fhir">
    <url value="http://hl7.ee/fhir/StructureDefinition/EEBase-Organization" />
    <name value="EEBaseOrganization"
    <version value="1.0.0" />
    <id value="EEBase-Organization" />
    <title value="EEBase Organization" />
</textarea>     
</div> 


<div class="callout callout-success">
<strong>Example of EducationLevel definition</strong><br/> 
<textarea rows="7" cols="80" style="border:none;">
<StructureDefinition xmlns="http://hl7.org/fhir">
    <url value="http://tehik.ee/fhir/StructureDefinition/EEBase-Observation-SocialHistory-Education" />
    <name value="EEBase Observation SocialHistory Education"
    <version value="0.9.1" />
    <id value="EEBase-Observation-SocialHistory-Education" />
    <title value="EEBase Observation SocialHistory Education" />
</textarea>     
</div> 

  </div>
</div>


<div class="card border-success mb-3" id="fhir-name-02">
  <div class="card-header bg-success">
   <strong class="card-title"><i class="bi bi-check-circle-fill"></i> FHIR-NAME-02 Convention for Extension definition</strong>
   <a href="#fhir-name-02"><i class="bi bi-link-45deg"></i></a>
  </div>
  <div class="card-body">
    <ul>
      <li>FHIR Extension MUST follow an agreed format.</li>
      <li>The <b>url</b> of a Extension consists of a number of name segments, and will be in the form: <br/>https://[<b>base url</b>]/fhir/StructureDefinition/Extension-[<b>Base</b>]-[<b>BusinessName</b>]
        <ul>
          <li><b>Base url:</b> The url used for standard publishing. <i>See profile definition.</i> </li>
          <li><b>Base:</b> The standard provider name. <i>See profile definition.</i> <b>Mandatory</b></li>
          <li><b>BusinessName:</b> The business name of the Extension. <b>Mandatory</b></li>
          <li>No business version information is allowed in the  Extension url</li>
        </ul>  
      </li>     
      <li><b>Resource name:</b> "Extension", [Base] and [BusinessName] without Hyphen (-) SHOULD be used as resource name.</li>           
      <li><b>Resource id:</b> The specification does not specify the form of resource id. "Extension", [Base] and [BusinessName] with Hyphen (-) RECOMMENDED as resource id.</li>  
      <li><b>Title:</b> The title of the resource MUST be [Base] and [BusinessName] and word "extension" with added spaces to make it human readable and understandable.</li>           
    </ul>

<div class="callout callout-success">
<strong>Example of ADS extension definition</strong><br/> 
<textarea rows="7" cols="80" style="border:none;">
<StructureDefinition xmlns="http://hl7.org/fhir">
    <url value="http://hl7.ee/fhir/StructureDefinition/Extension-EEBase-ADS" />
    <name value="ExtensionEEBaseADS"
    <version value="1.0.0" />
    <id value="Extension-EEBase-ADS" />
    <title value="Estonian ADS extension" />
</textarea>     
</div>  

  </div>
</div>



<div class="card border-success mb-3" id="fhir-name-03">
  <div class="card-header bg-success">
   <strong class="card-title"><i class="bi bi-check-circle-fill"></i> FHIR-NAME-03 Convention for OperationDefinition resource definition</strong>
   <a href="#fhir-name-03"><i class="bi bi-link-45deg"></i></a>
  </div>
  <div class="card-body">
    <ul>
      <li>FHIR OperationDefinition MUST follow an agreed format.</li>
      <li>The <b>url</b> of a OperationDefinition consists of a number of name segments, and will be in the form: <br/>https://[<b>base url</b>]/fhir/OperationDefinition/[<b>Base</b>]-[<b>BusinessName</b>]
        <ul>
          <li><b>Base url:</b> The url used for standard publishing. <i>See profile definition.</i></li>
          <li><b>Base:</b> The standard provider name. <i>See profile definition.</i><b>Mandatory</b></li>
          <li><b>BusinessName:</b> The business name of the OperationDefinition. <b>Mandatory</b></li>
          <li>No business version information is allowed in the  OperationDefinition url</li>
        </ul>  
      </li>     
      <li><b>Resource name:</b> [Base] and [BusinessName] without Hyphen (-) SHOULD be used as resource name.</li>           
      <li><b>Resource id:</b> The specification does not specify the form of resource id. [Base] and [BusinessName] with Hyphen (-) RECOMMENDED as resource id.</li>  
      <li><b>Title:</b> The title of the resource MUST be [Base] and [BusinessName] with added spaces to make it human readable and understandable.</li>           
    </ul>

<div class="callout callout-success">
<strong>Example of Estonian base Organization definition</strong><br/> 
<textarea rows="7" cols="80" style="border:none;"> 
<OperationDefinition xmlns="http://hl7.org/fhir">
    <url value="http://hl7.org/fhir/OperationDefinition/EEBase-PatientMerge"/> 
    <id value="EEBase-PatientMerge"/>
    <name value="EEBasePatientMerge"/>
    <version value="1.0.0" />
</textarea>     
</div> 

  </div>
</div>


<div class="card border-success mb-3" id="fhir-name-04">
  <div class="card-header bg-success">
   <strong class="card-title"><i class="bi bi-check-circle-fill"></i> FHIR-NAME-04: External CodeSystem and ValueSet names</strong>
   <a href="#fhir-name-04"><i class="bi bi-link-45deg"></i></a>
  </div>
  <div class="card-body">
    <ul>
        <li>The FHIR managed <a href="https://www.hl7.org/fhir/terminologies-systems.html">CodeSystems</a> should use names defined by FHIR working groups.</li>
        <li>The FHIR managed <a href="https://www.hl7.org/fhir/terminologies-valuesets.html">ValueSets</a> should use names defined by FHIR working groups.</li>
        <li>Some ValueSets that use SNOMED CT will refer directly to SNOMED CT artefacts for example SNOMED CT Ref Sets and there will not be a need to create a CodeSystem resource. There many be other ValueSets which follow the same principles, for example LOINC.</li>
    </ul>
  </div>
</div>




<div class="card border-success mb-5" id="fhir-name-05">
  <div class="card-header bg-success">
   <strong class="card-title"><i class="bi bi-check-circle-fill"></i> FHIR-NAME-05: CodeSystem name convention</strong>
   <a href="#fhir-name-05"><i class="bi bi-link-45deg"></i></a>
  </div>
  <div class="card-body">
    <ul>
        <li>FHIR CodeSystem names MUST follow an agreed format.</li>
        <li>The <b>url</b> of a CodeSystem consists of a number of name segments, and will be in the form: <br/>https://[<b>base url</b>]/CodeSystem/[<b>Base</b>]-[<b>BusinessName1</b>]-[<b>BusinessName2</b>]
        <li>The segments are defined as follows:
          <ul>
            <li><b>Base url:</b> The url used for standard publishing. <i>See profile definition.</i></li>
            <li><b>Base:</b> The standard provider name. <i>See profile definition.</i> <b>Mandatory</b></li>
            <li><b>BusinessNames:</b> The business names of the CodeSystem. The CodeSystem name MUST have at least one BusinessName segment. Where a CodeSystem MAY be used across several domains, business names SHOULD reflect that. <b>Mandatory</b></li>            
          </ul> 
        </li>
        <li><b>Resource name:</b> [Base] and [BusinessNames] without Hyphen (-) SHOULD be used as resource name.</li>                <li><b>Resource id:</b> [Base] and [BusinessNames] in lower case where every word separated with hyphen (-). Same formating rules SHOULD be applied to resource url.</li>  
        <li><b>Title:</b> The title of the resource MUST be [Base] and [BusinessNames] with added spaces to make it human readable and understandable.</li>   
        <li>The CodeSystems name MUST be used as the CodeSystems's filename.</li> 
    </ul>

<div class="callout callout-success">
<strong>Example of MaritalStatus Code System</strong><br/> 
<textarea rows="7" cols="80" style="border:none;">
<CodeSystem xmlns="http://hl7.org/fhir">
    <id value="eebase-marital-status"/> 
    <url value="https://hl7.ee/CodeSystem/eebase-marital-status"/> 
    <version value="2022-04-22"/> 
    <name value="EEBaseMaritalStatus"/> 
    <title value="Estonian Code System MaritalStatus"/> 
</textarea>     
</div>  
       
  </div>
</div>




<div class="card border-success mb-3" id="fhir-name-06">
  <div class="card-header bg-warning">
   <strong class="card-title"><i class="bi bi-check-circle-fill"></i> FHIR-NAME-06: ValueSet name convention</strong>
   <a href="#fhir-name-06"><i class="bi bi-link-45deg"></i></a>
  </div>
  <div class="card-body">
    <ul>
        <li>FHIR ValueSet names MUST follow an agreed format.</li>
        <li>The <b>url</b> of a ValueSet consists of a number of name segments, and will be in the form: <br/>https://[<b>base url</b>]/ValueSet/[<b>Base</b>]-[<b>BusinessName1</b>]-[<b>BusinessName2</b>]
        <li>The segments are defined as follows:
          <ul>
            <li><b>Base url:</b> The url used for standard publishing. <i>See profile definition.</i></li>
            <li><b>Base:</b> The standard provider name. <i>See profile definition.</i><b>Mandatory</b></li>
            <li><b>BusinessNames:</b> The list of business name of the ValueSet. The ValueSet name MUST have at least one BusinessName segment. Where a ValueSet MAY be used across several domains, business names SHOULD reflect that. <b>Mandatory</b></li>            
          </ul> 
        </li>
        <li><b>Resource name:</b> [Base] and [BusinessNames] without Hyphen (-) SHOULD be used as resource name.</li>                <li><b>Resource id:</b> [Base] and [BusinessNames] in lower case where every word separated with hyphen (-). Same formating rules SHOULD be applied to resource url.</li>  
        <li><b>Title:</b> The title of the resource MUST be [Base] and [BusinessNames] with added spaces to make it human readable and understandable.</li>   
        <li>The ValueSet name MUST be used as the ValueSet's filename.</li> 
    </ul>

<div class="callout callout-success">
<strong>Example of MaritalStatus ValueSet definition</strong><br/> 
<textarea rows="7" cols="80" style="border:none;">
<ValueSet xmlns="http://hl7.org/fhir">
    <id value="eebase-marital-status"/> 
    <url value="https://hl7.ee/ValueSet/eebase-marital-status"/> 
    <version value="4.0.1"/> 
    <name value="EEBaseMaritalStatus"/> 
    <title value="Estonian Marital Status Codes"/> 
</textarea>     
</div>  
       
  </div>
</div>





<div class="card border-success mb-3" id="fhir-name-07">
  <div class="card-header bg-warning">
   <strong class="card-title"><i class="bi bi-check-circle-fill"></i> FHIR-NAME-07: Identifier systems name convention</strong>
   <a href="#fhir-name-07"><i class="bi bi-link-45deg"></i></a>
  </div>
  <div class="card-body">
    <ul>
        <li>FHIR identifier systems MUST follow an agreed format.</li>
        <li>The identifier systems may be used in the system element of the Identifier datatype. They establish the namespace for an asset's identifier.value element and have a URI datatype.</li>
        <li>The <b>url</b> of a identifier systems consists of a number of name segments, and will be in the form: <br/>https://[<b>base url</b>]/NamingSystem/[<b>BusinessName1</b>]-[<b>BusinessName2</b>]-[<b>BusinessName3</b>]-[<b>BusinessName4</b>]
        <li>The segments are defined as follows:
          <ul>
            <li><b>Base URL:</b> The url used for standard publishing. <i>See profile definition.</i></li>
            <li><b>NamingSystem:</b> The NamingSystem section of the identifier is formatted as a string 'NamingSystem'. This segment denotes that the string is an identifier system and is <b>Mandatory</b></li>
            <li><b>BusinessNames:</b> The business name segments describe the identifier system. The first business name is Mandatory, but all subsequent ones are optional. There may be up to four business names each separated by a hyphen (-) character e.g.</li>            
          </ul> 
        </li>
        <li>Business names SHOULD be used as the logical ID in lower case.</li> 
    </ul>

<div class="callout callout-success">
<strong>Example of NamingSystem definition for Estonian personal identification code</strong><br/> 
<textarea rows="17" cols="80" style="border:none;">
    "fullUrl" : "https://hl7.ee/NamingSystem/est-id-number",
    "resource" : {
      "resourceType" : "NamingSystem",
      "id" : "est-id-number",
      "name" : "Estonian personal identification code",
      "uniqueId" : [{
        "type" : "uri",
        "value" : "https://hl7.ee/id/est-personal-code",
        "preferred" : true
      },
      {
        "type" : "oid",
        "value" : "1.3.6.1.4.1.28284.6.2.2.1",
        "preferred" : false
      }]
    }
</textarea>     
</div>  
       
  </div>
</div>




