# {{page-title}}
Patient is an entity receiving or registered to receive medical treatment.

<div class="alert alert-warning">

**Work in progress.**\
This section of the Implementation Guide is subject to change.

</div>

<br/>

#### Base profile
This profile allows exchange of demographics and other administrative information about an individual receiving care or other health-related services in Estonia.
{{render:https://hl7.ee/fhir/StructureDefinition/EEBase-Patient, hybrid}}

<br/>

#### Minimal Viable Content
Each Patient must have:
- a patient identifier (e.g. MRN)
- a patient name
- an activity status
<br/>All other elements are optional.

Each implementer of Patient profile must support:
- a gender
- a birth date
- a deceased information
- an address?

<br/><code>identifier</code><br/>
In Estonia at least one identifier should have type with value MR (Medical Record Number) to identify the patient's NHS number. 

Additional identifiers can also be added. 

Please follow <a href="#">link</a> to read about all supported identity systems.
<div class="callout callout-success">
  <strong>Example of patient identifier</strong><br/> 
  <textarea rows="17" cols="80" style="border:none;">
  "identifier" : [
    {
      "use" : "usual",
      "type" : {
        "coding" : [
          {
            "system" : "http://hl7.org/fhir/ValueSet/identifier-type",
            "code" : "MR",
            "display" : "Medical Record Number"
          }
        ],
        "text" : "Medical Record Number"
      },
      "system" : "http://hl7.ee/id/est-id",
      "value" : "37302102711"
    }    
  </textarea>
</div> 


<br/><code>name</code><br/>
The patient name represented by the HumanName data type.
Multiple names can be included.

|Attribute|Description|
|-
|use|Specify context of usage: official - name based on identification document, old - previous name, nickname - name for unknown or non-human patient|
|family|Last name |
|given|Fist name|
|text|Display name used for unknown or anonymous or non-human patient|
|period|Activity period of name|

<div class="callout callout-success">
  <strong>Example of changed patient name</strong><br/> 
  <textarea rows="20" cols="80" style="border:none;">
  "name": [
    {
      "use": "official",
      "family": "Kaalikas",
      "given": [
        "Kalle"
      ]
    },
    {
      "use": "old",
      "family": "Juurikas",
      "given": [
        "Kalle"
      ],
      "period": {
        "end": "2022-04-18"
      }
    }
  ]   
  </textarea>
</div> 
When a patient tagged with security label "very restricted", all names are removed from the response.


<br/><code>active</code><br/>
A _boolean_ value indicating if the patient's record is in current use.

Typically it will be used to mark a duplicated record or record created in error with the link element pointing to the active record.

<br/><code>gender</code><br/>
_Administrative Gender_ - the gender that the patient is considered to have for administration and record keeping purposes.


<br/><code>birthDate</code><br/>
The patient's date of birth. An approximate date may be used (e.g. just the year) where the full date is not known.

_birthDate_ includes an general extension _patient-birthTime_. This should be used when the birth time is relevant.


<br/><code>deceased</code><br/>
Either:
A ```boolean``` value indicating the patient is dead

or

the ```DateTime``` of death.

Where the patient is alive sending systems can omit this element, it is not necessary to include it to indicate that the patient is not dead.

Where this element is missing, receiving systems can assume the patient is alive.


<br/><code>address</code><br/>
The address of the patient using the address datatype.
A patient may have multiple addresses with different uses or applicable periods.

_address_ includes an [EHAK](https://simplifier.net/ee-base/extension-eebase-ehak) and [ADS](https://simplifier.net/ee-base/extension-eebase-ads) extension. 

At least one extension should be used within address.

<br/><code>contact</code><br/>
A contact relevant to the care of the patient and may include family members, business contacts, guardians, caregivers, etc.

Contact should not be used to represent family genealogy.

Contact includes an common extension patient-relativePerson and EHAK/ADS extensions for contact.address. 

<br/><code>maritalStatus</code><br/>
Marital status of human patient. Defined as [TODO Marital Status Codes](http://terminology.hl7.ee/ValueSet/ee-marital-status)  

<br/><code>generalPractitioner</code><br/>
The patient's GP by reference to EEBase-Practitioner for the GP and/or EEBase-PractitionerRole for the patient's GP and GP practice.

<br/><code>managingOrganization</code><br/>
Organisation that is the custodian of the patient record. KAS MEILE SEDA VAJA??!!!

This is a reference to the "Organisation that is the custodian of the patient record" (such as a general practice).

The managingOrganization may change according to the setting (a mental health record may be managed by a MH trust), whereas the generalPractitioner points to your GP or GP Practice.


<br/><code>link</code><br/>
Link to another patient resource that concerns the same patient either to another Patient Resource such as a duplicate record. 

<br/>


#### List of profiles
There are many usecase for processing patient data. Separate profiles regulate documentation rules in specific context.

|Description|Profile|Usage|
|
|Base of Estonian Patient|[EeBasePatient](https://simplifier.net/ee-base/eebase-patient)|Root for other patient profiles|
|Unknown patient|[EeBasePatientUnknown](https://simplifier.net/ee-base/eebase-patient-unknown)|For use in ED, ambulance, for anonymous patients and environmental tests|
|Animal Patient|[EeBasePatientAnymal](https://simplifier.net/ee-base/eebase-patient-animal)|For veterinarian, laboratories and pathology needs|
|Newborn Patient|[EeBasePatientNewborn](https://simplifier.net/ee-base/eebase-patient-newborn)|For supporting maternity and newborn workflows|
|Example profile|[TisPatient](https://simplifier.net/ee-base/tis-patient)|Experimental profile with official extensions|

<br/>

#### Unknown Patient
Unknown patient profile inherited from Estonian Base Patient profile.
The limited set of data MAY BE used during unknown patient registration in Emergency Department, Ambulance, etc


{{tree:https://hl7.ee/fhir/StructureDefinition/EeBase-Patient-Unknown, hybrid}}

<code>identifier</code><br/>
Hospital identifier for unknown patient SHOULD be used. _temp_ is fixed for _Patient.identifier.use_ in hospital identifier.

<br/><code>name</code><br/>
_nickname_ is fixed as the name _use_ and the _name.text_ is only allowed field.

<br/><code>address</code><br/>
address.type SHOULD use value 'temp' identifying the place of patient finding.

<br/><code>birthDate</code><br/>
Added [Age](https://simplifier.net/ee-base/extension-eebase-patientage) extension due to exact date of birth unknown.

<br/>

#### Animal Patient
Animal patient profile inherited from Estonian Base Patient profile.
The animal patient does not have most of the characteristics of a human patient. As result the limited set of data MAY BE used during animal patient registration 

{{render:https://hl7.ee/fhir/StructureDefinition/EEBase-Patient-Animal, hybrid}}

<code>name</code><br/>
_nickname_ is fixed as the name _use_ and the _name.text_ is only allowed field.

<br/><code>birthDate</code><br/>
Added [Age](https://simplifier.net/ee-base/extension-eebase-patientage) extension due to exact date of birth unknown.

<br/><code>Animal extensions</code><br/>
Animal patient includes an general _animal_ extensions for species, breed and genderStatus. 

<br/>

#### Newborn Patient
Newborn patient profile inherited from Estonian Base Patient profile.
A profile for a newborn restricts the use of features that are not applicable to the newborn and adds elements that are unique to the newborn:
{{tree:https://hl7.ee/fhir/StructureDefinition/EEBase-Patient-Newborn, hybrid}}

<br/><code>birthDate</code><br/>
Added [Age](https://simplifier.net/ee-base/extension-eebase-patientage) extension in case when exact date of birth unknown.

Extension birthTime SHOULD be supported by implementors in case of newborn patient.

<br/><code>multipleBirth</code><br/>
_multipleBirth_ restricted by _```index```_ and is required

<br/><code>identifier</code><br/>
- identifikaatorite hulka lisatud surnult sündinu identifikaator mis tellitakse TAI käest (emaili teel)
- identifikaatorite hulka lisatud sünnitunnistuse number ja surmatunnistuse number (kas on vaja?)
- Tuleb uurida ka [VRDR info](https://build.fhir.org/ig/HL7/vrdr/artifacts.html)

<br/><code>Place of birth extension</code><br/>
Place of birth added as extension, which has been extended with EHAK and ADS codes

<br/><code>Adoption extension</code><br/>
Added adoption extension

<br/>

#### TIS Patient
TIS patsiendile lisatud kõik võimalikud ametlikud laiendid.
NAKIS juhendis on mõned tunnused mida ametlikke hulgas pole. Loetleme neid ja teeme ettepaneku lahendamiseks:
- Töötamise tunnus (alamhulk [sotsiaalsest staatusest](http://pub.e-tervis.ee/classifications/Sotsiaalmajanduslik%20seisund/4)) näide [US ODH tervishoiu profiilist](http://hl7.org/fhir/us/odh/StructureDefinition-odh-EmploymentStatus.html) ning valiku [variandid](https://phinvads.cdc.gov/vads/ViewValueSet.action?oid=2.16.840.1.114222.4.11.7129)
- Haridus ja õppeasutus
    - Haridus ja õppeasutus tuleb kirjeldada Observationina kuna see muutub ajas. 
    - Ametlikkest profiilidest on [DecedentEducationLevel](https://build.fhir.org/ig/HL7/vrdr/StructureDefinition-vrdr-decedent-education-level.html) VRDR-ist on ja [väärtused](https://build.fhir.org/ig/HL7/vrdr/ValueSet-vrdr-education-level-vs.html). Performer organizationina saab määrata õppeasutust.
- Töökoht ja amet
    - Kõigepealt töökoha asjad olid kirjeldatud kui [OHIS Occupational Health profiles](http://hl7.org/fhir/us/odh/artifacts.html)
    - Ning siis seda [UsusalWork](https://build.fhir.org/ig/HL7/vrdr/StructureDefinition-vrdr-decedent-usual-work.html) kasutati VRDR-is 
    - Veel üks näide [US Military Employment History-st](http://hl7.org/fhir/us/military-service/2021Sep/StructureDefinition-odh-EmploymentHistoryEpisode.html)
- Eesti kohased profiilid koondasin lehel "Social History"

{{render:https://hl7.ee/fhir/StructureDefinition/TIS-Patient, hybrid}}

<br/>

#### RelatedPerson
{{render:https://hl7.ee/fhir/StructureDefinition/EEBase-RelatedPerson, hybrid}}

<br/>

#### Terminology binding

|Path|Conformance|Description and link|
|-
|Patient.identifier.type| extensible| [Identifier Type Codes](http://hl7.org/fhir/R4/valueset-identifier-type.html)|
|Patient.identifier.use|	required|	[IdentifierUse](http://hl7.org/fhir/R4/valueset-identifier-use.html)|
|Patient.name.use|required|[NameUse](http://hl7.org/fhir/R4/valueset-name-use.html)|
|Patient.gender| required|[Administrative Gender](http://hl7.org/fhir/R4/valueset-administrative-gender.html)|
|Patient.maritalStatus| extensible| [Marital Status Codes](http://terminology.hl7.ee/ValueSet/ee-marital-status) |
|Patient.language| preferred|	[CommonLanguages](http://hl7.org/fhir/R4/valueset-languages.html)|
|Patient.telecom.system|	required|	[ContactPointSystem](http://hl7.org/fhir/R4/valueset-contact-point-system.html)|
|Patient.telecom.use|	required|	[ContactPointUse](http://hl7.org/fhir/R4/valueset-contact-point-use.html)|
|Patient.address.use|	required|	[AddressUse](http://hl7.org/fhir/R4/valueset-address-use.html)|
|Patient.address.type|	required|	[AddressType](http://hl7.org/fhir/R4/valueset-address-type.html)|
|Patient.contact.relationship|	extensible|	[PatientContactRelationship](http://hl7.org/fhir/R4/valueset-patient-contactrelationship.html)|
|Patient.contact.gender|	required|	[AdministrativeGender](http://hl7.org/fhir/R4/valueset-administrative-gender.html)|
|Patient.link.type|	required|	[LinkType](http://hl7.org/fhir/R4/valueset-link-type.html)|
|RelatedPerson.relationship| preferred| [PatientRelationshipType](https://www.hl7.org/fhir/valueset-relatedperson-relationshiptype.html)|
|RelatedPerson.gender| required| [AdministrativeGender](http://hl7.org/fhir/R4/valueset-administrative-gender.html)|
|RelatedPerson.communication.language| preferred| [CommonLanguages](http://hl7.org/fhir/R4/valueset-languages.html)|

